#!/usr/bin/env python
# -*- coding: utf-8 -*-

from pymongo import MongoClient

class Xxxx:
    def __init__(self):
        # Conecta ao banco de dados
        self.mongo_server = MongoClient("localhost", 27017)


Xxxx()


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
import unicodedata
from bson import Int64
from bson.timestamp import Timestamp
from bson.objectid import ObjectId



# TODO:: Testar possivel falha em str(inst.args)
class Check:
    def __init__(self):
        pass

    # --------------------------------
    # is_array
    # --------------------------------
    # Verifica se é um array
    # Retorna boolean
    #
    @staticmethod
    def is_array(value):
        return type(value) == list

    # --------------------------------
    # is_boolean
    # --------------------------------
    # Verifica se é boleano
    # Retorna boolean
    #
    @staticmethod
    def is_boolean(value):
        return type(value) == bool

    # --------------------------------
    # is_service_config
    # --------------------------------
    # Verifica se o objeto de configuração de serviços é válido
    @staticmethod
    def is_service_config(configs):
        keys = ["id", "type", "service_id", "ip"]
        status = False

        if type(configs) == dict:
            status = True
            for item in keys:
                if item not in configs.keys():
                    status = False
        return status

    # --------------------------------
    # is_date
    # --------------------------------
    # Verifica se é uma data
    # Retorna boolean
    #
    @staticmethod
    def is_date(value):
        status = False
        if (type(value) == dict) and ("$date" in value.keys()):
            status = (len(value["$date"]) == 24)
        return status

    # --------------------------------
    # is_decimal
    # --------------------------------
    # Verifica se é decimal
    # Retorna boolean
    #
    @staticmethod
    def is_decimal(value):
        status = False
        if (type(value) == dict) and ("$numberDecimal" in value.keys()) and re.match("""^-?[0-9]+\.?[0-9]*$""", value["$numberDecimal"]):
            status = (len(value["$numberDecimal"]) > 0) and (len(value["$numberDecimal"]) <= 34)
        return status

    # --------------------------------
    # is_default
    # --------------------------------
    @staticmethod
    def is_default(item_scheme):
        return 'default' in item_scheme.keys()

    # --------------------------------
    # is_empty
    # --------------------------------
    # Verifica se o valor do campo não está vazio ou é do tipo js null
    @staticmethod
    def is_empty(value):
        try:
            if type(value) == unicode:
                value = unicodedata.normalize('NFKD', value).encode('utf-8', 'ignore')
            else:
                value = str(value)
        except Exception:
            value = ''

        # Verifica se o campo é diferente de string e se não está vazio
        return (len(value) == 0) or (value == '')

    # --------------------------------
    # is_number
    # --------------------------------
    # Verifica se é número
    # Retorna boolean
    #
    @staticmethod
    def is_number(value):
        return (type(value) == Int64) and (value >= -9223372036854775808) and (value <= 9223372036854775807)

    # --------------------------------
    # is_object
    # --------------------------------
    # Verifica se é objeto
    # Retorna boolean
    # TODO:: Implementar validação recursiva para valores numéricos
    #
    @staticmethod
    def is_object(value):
        return (type(value) == dict) and ("error" not in value.keys())

    # --------------------------------
    # is_object_id
    # --------------------------------
    # Verifica se é objectId
    # Retorna boolean
    #
    @staticmethod
    def is_object_id(value):
        return type(value) == ObjectId

        # --------------------------------

    # is_scheme
    # --------------------------------
    @staticmethod
    def is_scheme(scheme):
        if type(scheme) == dict:
            list_scheme = ["$currentDate", "$inc", "$min", "$max", "$mul", "$rename", "$set", "$setOnInsert", "$unset"]
            for key in scheme.keys():
                if key in list_scheme:
                    return True
        return False

    # --------------------------------
    # is_string
    # --------------------------------
    # Verifica se é string
    # Retorna boolean
    #
    @staticmethod
    def is_string(value):
        return (type(value) == unicode) or (type(value) == str)

    # --------------------------------
    # is_timestamp
    # --------------------------------
    # Verifica se é timestamp
    # Retorna boolean
    #
    @staticmethod
    def is_timestamp(value):
        return type(value) == Timestamp



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import zmq
from core import Core
from convert import Convert
from service_db import ServiceDB

# TODO:: Implementar autoconfiguração do serviço, comunicação com console admin
class DevdooDatabases(Core):
    # --------------------------------
    # Error
    # --------------------------------
    # TODO:: Remover classe de error
    class Error(Exception):
        pass

    # --------------------------------
    # __init__
    # --------------------------------
    def __init__(self):
        super(DevdooDatabases, self).__init__()



        # Serviço a ser executado
        self.service = None
        self.config = self.init_config()

        if self.config.ready():
            self.__start()
        else:
            # TODO:: Enviar para o servidor console a informação de falha de configuração
            print Convert.to_str("AAA - FALHA NA INICIALIZACAO DO DEVDOO-BROKER-SERVICE")
            print "ERROR", self.status.to_list()

    # --------------------------------
    # __start
    # --------------------------------
    def __start(self):
        if self.__is_start_services() is True:
            # Cria contexto ZMQ
            context = zmq.Context()

            # Adaptador de conexão
            self.socket_frontend = context.socket(zmq.REP)
            self.socket_frontend.connect(self.config.broker_database_endpoint)

            print "AAAA- RUN"

            self.run()

        else:
            print "BBB - FALHA NA INICIALIZAÇÃO DO DEVDOO-BROKER-SERVICE"

    # --------------------------------
    # __is_start_services
    # --------------------------------
    def __is_start_services(self):
        self.config.load_devdoo_databases()
        return self.config.ready()

    # --------------------------------
    # console_service_list
    # --------------------------------
    # Obtém da console a lista de configuração
    #
    # TODO:: Remover console_service_list, implementar sistema de autoconfiguração
    def console_service_list(self, server_console, service_id):
        return server_console[service_id]

    # --------------------------------
    # operation
    # --------------------------------
    # Executa a ação do Serviço
    #
    # TODO:: Implementar controle ready antes de seguir adiante
    def operation(self):
        # Recebe do mensagem do servidor cliente
        self.process(self.socket_frontend.recv())

        # Processa a operacao e envia mensage de retorno para o cliente
        self.socket_frontend.send(self.service.send())

    # --------------------------------
    # process
    # --------------------------------
    # Inicia o Serviço de banco
    #
    # TODO:: Mudar a forma como deverá ser configurado o serviço
    def process(self, message):
        self.service = ServiceDB(message, self.config)

    # --------------------------------
    # run
    # --------------------------------
    # Executa a operação em um loop infinito
    #
    # TODO:: Implementar ping de verificação de disponibilidade do serviço
    def run(self):
        while True:
            try:
                self.operation()
            except DevdooDatabases.Error:
                pass
                # except Exception as inst:
                #    print "API_DB::RUN::ERROR", inst.args



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from endpoint import Endpoint
from pprint import pprint

class Actions:
    def __init__(self, database, status):
        self.status = status
        self.__endpoints = {}
        self.__prepare_scheme(database)

    # --------------------------------
    # endpoint
    # --------------------------------
    def endpoint(self, source):
        if source in self.__endpoints.keys():
            return self.__endpoints[source]
        else:
            return None

    # --------------------------------
    # __collection
    # --------------------------------
    def __collection(self, uri, item, collections):
        collection = None
        name = None
        if "collection" in item.keys():
            name = item["collection"]
            if name in collections.keys():
                collection = collections[name]["schemes"]
            else:
                self.status.error("COLLECTION_INVALID", None, [name])
        else:
            self.status.error("COLLECTION_INVALID_IDENTIFIER", None, [uri])

        return name, collection

    # --------------------------------
    # __fields_public
    # --------------------------------
    @staticmethod
    def __fields_public(item, schemes):
        for i in schemes:
            if "public" in schemes[i].keys():
                item["scheme"][i] = schemes[i]
                if schemes[i]["public"] is True:
                    (item["fields"]["public"]).append(schemes[i]["field"])

        return item

    # --------------------------------
    # __prepare_scheme
    # --------------------------------
    def __prepare_scheme(self, database):
        collections = database["collections"]
        actions = database["actions"]
        for method in actions:
            endpoint = actions[method]
            for item in endpoint:
                name, schemes = self.__collection(item, endpoint[item], collections)
                if schemes is not None:
                    if self.__check_endpoint(item, endpoint[item]):
                        endpoint[item] = self.__fields_public(endpoint[item], schemes)
                        endpoint[item]["fields"]["default"] = self.__check_conflit_fields(endpoint[item]["fields"]["default"])
                        endpoint[item]["fields"]["public"] = self.__check_conflit_fields(endpoint[item]["fields"]["public"])
                        self.__endpoints[item] = Endpoint(item, endpoint[item], self.status)
                        if method == "put":
                            print "PUT", "----->>>"
                            pprint(endpoint[item])

    # --------------------------------
    # __check_endpoint
    # --------------------------------
    def __check_endpoint(self, uri, endpoint):
        errors = []
        if "action" not in endpoint.keys():
            errors.append("ACTION")

        if "collection" not in endpoint.keys():
            errors.append("COLLECTION")

        if "fields" not in endpoint.keys():
            errors.append("FIELDS")

        if "scheme" not in endpoint.keys():
            errors.append("SCHEME")

        if "type" not in endpoint.keys():
            errors.append("TYPE")

        if "max_limit" not in endpoint.keys():
            errors.append("MAX_LIMIT")

        if len(errors) > 0:
            self.status.error("INVALID_ENDPOINT_PARAMS", None, [(",".join(errors)), uri])
            return False
        else:
            return True

    # --------------------------------
    # __check_conflit_fields
    # --------------------------------
    # Verifica se existe conflito de nomes de campos em modo desenvolvimento de microserviços
    # Não permite incluir na lista campos pai que possuem campos filhos que podem sobrepor informações
    def __check_conflit_fields(self, fields_default):
        fields_clean = []
        fields_errors = {}

        # Processa a lista de campos default
        for item_check in fields_default:
            # Retira um item da lista para comparar com outros itens da mesma lista
            for item_field in fields_default:
                # Caso um campo esteja em conflito com outros campos é adicionado na lista de erros
                if item_check + '.' in item_field:
                    fields_errors[item_check] = True

        # Gera a lista de campos default sem os campos que foram encontrados conflitos
        for item_field in fields_default:
            if item_field not in fields_errors.keys():
                fields_clean.append(item_field)

        if len(fields_errors) > 0:
            self.status.error("FIELD_CONFLICT", None, [(",".join(fields_errors))])

        return fields_clean



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import i18n
import yaml
from actions import Actions
from devdoo_services import DevdooServices
from devdoo_databases import DevdooDatabases
from check import Check
from config import Config
from console import Console
from convert import Convert
from core import Core
from devdoo_brokers import DevdooBrokers
from database import DataBase
from datafilter import DataFilter
from datarest import DataRest
from endpoint import Endpoint
from package import Package
from datarest_db import DataRestDB
from service import Service
from service_db import ServiceDB
from status import Status
from validate import Validate



#docker exec -it 4551555545454 python ./pastas/add_services.py


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import zmq
from zmq.sugar.socket import Socket
from core import Core
from convert import Convert
from package import Package


class DevdooBrokers(Core):
    # --------------------------------
    # Error
    # --------------------------------
    # TODO:: Remover classe de error
    class Error(Exception):
        pass

    # --------------------------------
    # __init__
    # --------------------------------
    def __init__(self):
        super(DevdooBrokers, self).__init__()

        self.config = self.init_config()

        # Inicializa variável de conexão
        self.socket_backend = None

        if self.config.ready():
            # Cria contexto ZMQ
            self.context = zmq.Context()
            # Inicializa o poll set
            self.poller = zmq.Poller()

            self.__start()
        else:
            # TODO:: Enviar para o servidor console a informação de falha de configuração
            print Convert.to_str("AAA - FALHA NA INICIALIZACAO DO DEVDOO-BROKER-SERVICE")
            print "ERROR", self.status.to_list()

    # --------------------------------
    # __start
    # --------------------------------
    def __start(self):

        if self.__is_start_services() is True:
            broker_endpoint = "tcp://*:" + Convert.to_str(self.config.service_id)

            # Abre porta para o Restify (frontend)
            self.socket_frontend = self.context.socket(zmq.ROUTER)
            self.socket_frontend.bind(broker_endpoint)
            self.poller.register(self.socket_frontend, zmq.POLLIN)

            self.run()
        else:
            print "BBB - FALHA NA INICIALIZAÇÃO DO DEVDOO-BROKER-SERVICE"

    # --------------------------------
    # __is_start_services
    # --------------------------------
    def __is_start_services(self):
        status = False

        list_services = self.config.load_devdoo_brokers()

        if self.config.ready():
            # Abre portas para os Serviços
            self.available_services = {}
            for item in list_services:
                # Define o endpoint do serviço
                service_id = Convert.to_str(item["service_id"])
                endpoint = "tcp://*:" + service_id

                # Abre portas para os Serviços no backend
                socket_backend = self.context.socket(zmq.DEALER)
                socket_backend.bind(endpoint)

                # TODO:: Implementar Lista de serviços do mesmo tipo
                # TODO:: Aprimorar registro do serviço no stack
                # Armazena a conexão do backend no stack
                self.available_services[service_id] = socket_backend

            if len(self.available_services.keys()) > 0:
                status = True

        return status

    # --------------------------------
    # operation
    # --------------------------------
    # Permuta pacotes entre o frontend e o backend
    #
    # TODO:: Verificar se existe um serviço para o service_id solicitado antes de tentar pegar na lista
    # TODO:: Verificar se o serviço está disponível antes de tentar fazer conexão
    # TODO:: Verificar se a mensagem foi corretamente convertida de string para dic antes de tentar pegar um elemento
    # TODO:: Procurar formas de desregistrar sockets que não obtiveram respostas dentro do tempo limite
    def operation(self):
        # Poller de sockets
        socks = dict(self.poller.poll())

        # Verifica se o socket chegou do REST ou Serviço
        if socks.get(self.socket_frontend) == zmq.POLLIN:
            # Recebe mensagem do Restify
            message = self.socket_frontend.recv_multipart()

            # Recupera o socket de conexao do serviço
            self.socket_backend = self.__find_socket(message)

            # Verifica se o socket é valido
            if type(self.socket_backend) == Socket:
                print "SOCKET VALIDO ENVIOU ADIANTE", "----->>>>"
                # Registra o socket no poller ZMQ para dar acesso aos workers
                self.poller.register(self.socket_backend, zmq.POLLIN)

                # Envia ao Service Work a mensagem com pacote de dados
                self.socket_backend.send_multipart(message)
                print "SOCKET VALIDO VOLTOU", "----->>>>"

            else:
                print "FALHOU, VOLTOU PARA REST", "----->>>>"
                # Caso contrario retorna para o cliente sem realizar nenhuma alteração
                message[2] = self.socket_backend
                self.socket_frontend.send_multipart(message)

        # Verifica se o socket retornou do Service Worker
        if socks.get(self.socket_backend) == zmq.POLLIN:
            # Recebe do Service Worker
            message = self.socket_backend.recv_multipart()

            # Retorna ao Restify
            self.socket_frontend.send_multipart(message)
            self.poller.unregister(self.socket_backend)

    # --------------------------------
    # process
    # --------------------------------
    # Assinatura do método process para sobrescrita
    #
    def process(self, data):
        raise DevdooBrokers.Error("`process` should be overriden")

    # --------------------------------
    # run
    # --------------------------------
    # Executa a operação em um loop infinito
    #

    def run(self):
        while True:
            try:
                self.operation()
            except DevdooBrokers.Error:
                pass
            #except Exception as inst:
            #    print "BROKER::RUN::ERROR", inst.args

    # --------------------------------
    # __find_socket
    # --------------------------------
    def __find_socket(self, message):
        package = Package(message)

        # Verifica se mensagem é string
        if package.is_valid() is True:
            if package.active_port in self.available_services.keys():
                return self.available_services[package.active_port]
            else:
                # TODO:: Envia para o console mensagem de erro de serviço não disponível
                self.status.error("INVALID_SERVICE", None, ["Servico nao disponível no servidor BROKER", package.active_port])


        return package.to_string()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from actions import Actions
from convert import Convert
from check import Check


# TODO:: Refatorar completamente a classe DataBase
class DataBase:
    # --------------------------------
    # __init__
    # --------------------------------
    def __init__(self, database, status):
        self.status = status

        self.id = database["id"]
        self.network = database["network"]
        self.collections = database["collections"]
        self.actions = Actions(database, self.status)

    # --------------------------------
    # active_service
    # --------------------------------
    def active_service(self):
        return self.network["port"]

    # --------------------------------
    # endpoint
    # --------------------------------
    def endpoint(self, source):
        return self.actions.endpoint(source)

    # --------------------------------
    # fields_insert
    # --------------------------------
    # Prepara a lista de campos que pode ser incluída na base de dados
    #
    def fields_insert(self, body, endpoint):
        list_scheme_clean = {}

        # Verifica se o campo tem valor default
        for item_name in endpoint.scheme:
            # Pega um esquema da lista
            item_scheme = endpoint.scheme[item_name]
            # Verifica se o campo tem valor default ou é requerido
            if Check.is_default(item_scheme) or self.__required(item_scheme):
                # Registra o dot field name do campo
                item_scheme["field"] = item_name
                # Verifica se o valor do campo não é vazio
                # Registra o valor do campo
                item_scheme["value"] = Convert.to_empty(item_scheme, self.__default(item_scheme))
                # Registra o schema válido na lista de esquema limpa
                list_scheme_clean[item_name] = item_scheme

        # Processa todos os campos de body para colocar em letra minuscula e criar lista de campos validos
        for item_body_field in body:
            # Processa o nome do campo recebido no body
            body_field = item_body_field.replace(' ', '_').lower().strip()

            # Verifica se o campo recebido via body esta configurado no esquema
            item_name, item_scheme = self.__check_body_item_scheme(body_field, endpoint.scheme)

            # Caso o campo recebido via body está registrado no esquema então adiciona na lista de esquema limpa
            if item_scheme is not None:
                # Registra o dot field name do campo
                item_scheme["field"] = item_name
                # Verifica se o valor do campo não é vazio
                # Registra o valor do campo
                item_scheme["value"] = Convert.to_empty(item_scheme, body[item_body_field])
                # Registra o schema válido na lista de esquema limpa
                list_scheme_clean[item_name] = item_scheme

            # Caso o campo nao esteja registrado no scheme, registra na lista de campos com erro
            if item_body_field not in endpoint.fields(False):
                # Caso o campo nao esteja registrado no scheme, registra mensagem de error
                self.status.error("DOES_NOT_EXIST_FIELD", None, [item_body_field])

        return list_scheme_clean

    # --------------------------------
    # fields_update
    # --------------------------------
    def fields_update(self, body, list_scheme):
        fields_default = self.__fields_default(list_scheme)

        list_scheme_clean = {}
        body_field_errors = []

        # Processa todos os campos de body para colocar em letra minuscula e criar lista de campos validos
        for item_body_field in body:
            body_field = item_body_field.replace(' ', '_').lower().strip()
            item_name, item_scheme = self.__check_body_item_scheme(body_field, list_scheme)

            if item_scheme is not None:
                item_scheme["field"] = item_name
                item_scheme["value"] = Convert.to_empty(item_scheme, body[item_body_field])
                list_scheme_clean[item_name] = item_scheme

            # Caso o campo nao esteja registrado no scheme, registra mensagem de error
            if item_body_field not in fields_default:
                body_field_errors.append(item_body_field)

        return list_scheme_clean, body_field_errors

    # --------------------------------
    # __check_body_item_scheme
    # --------------------------------
    # Verifica se o campo recebido via body esta configurado no esquema
    @staticmethod
    def __check_body_item_scheme(body_field, list_scheme):
        for item_scheme in list_scheme:
            if item_scheme == body_field:
                return item_scheme, list_scheme[item_scheme]
        return None, None

    # --------------------------------
    # __default
    # --------------------------------
    @staticmethod
    def __default(item_scheme):
        value = ""
        if 'default' in item_scheme.keys():
            value = item_scheme['default']
        return value

    # --------------------------------
    # __required
    # --------------------------------
    @staticmethod
    def __required(item_scheme):
        value = False
        if 'required' in item_scheme.keys():
            value = item_scheme['required']
        return value



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from console import Console
from database import DataBase
from pymongo import MongoClient
from pprint import pprint


class Config:
    def __init__(self, config, status):
        self.status = status
        self.__ready = True
        self.id = config["id"]

        print "INIT SERVICE ID::", self.id
        self.console = Console()

    def load_devdoo_services(self):
        self.__ready = False
        config = self.console.load_config(self.id)

        if len(config.keys()) > 1:
            # Define parâmetros globais
            self.name = config["name"]
            self.type = config["type"]
            self.network = config["network"]
            self.version = config["version"]
            self.database = DataBase(config["database"], self.status)
            self.endpoint_broker_rest = config["endpoints"]["broker_rest"]
            self.endpoint_broker_database = config["endpoints"]["broker_database"]
            self.active_service = self.database.active_service()

            # self.schemes = config["schemes"]
            # self.service_id = self.network["port"]
            # self.database_id = self.database["network"]["port"]

            self.__ready = True

    def load_devdoo_databases(self):
        self.__ready = False
        config = self.console.load_config(self.id)
        if len(config.keys()) > 1:
            # Define endpoints de conexão
            self.broker_database_endpoint = config["broker_database_endpoint"]

            mongodb_ip = config["mongodb_ip"]
            mongodb_port = int(config["mongodb_port"])

            self.mongo_server = MongoClient(mongodb_ip, mongodb_port)

            self.__ready = True

    def load_devdoo_brokers(self):
        self.__ready = False
        config = self.console.load_config(self.id)

        if (self.console.ready()):
            self.name = config["name"]
            self.type = config["type"]
            self.network = config["network"]
            self.version = config["version"]
            self.services = config["services"]
            self.service_id = self.network["port"]  # isso vai morrer

            self.__ready = True
            return self.services

    def ready(self):
        if self.status.ready() is False:
            pprint(self.status.to_list())
        return self.status.ready()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import yaml
import os
import sys
from check import Check
from config import Config
from convert import Convert
from status import Status


class Core(object):
    # --------------------------------
    # __init__
    # --------------------------------
    def __init__(self):

        self.status = Status()

    # --------------------------------
    # init_config
    # --------------------------------
    # Recupera informações de configurações do broker
    def init_config(self):
        # Tenta pegar configurações docker
        devdoo_config = os.environ.get('devdoo')

        # Caso não tenha sucesso
        if not devdoo_config:
            # Tenta pegar configurações de arquivo local
            devdoo_config = self.__config_local()

        if Check.is_service_config(devdoo_config):
            return Config(devdoo_config, self.status)
        else:
            self.status.error("CONFIGURATION_SERVICE", None, ["Arquivo de configuracao invalido"])
            return None

    # --------------------------------
    # __config_local
    # --------------------------------
    # Recupera informações de configuração em arquivo local
    def __config_local(self):
        config_local = None
        file_open = None

        if len(sys.argv) > 1:
            # Recupera o endereço do arquivo de configuração
            path_file = str(sys.argv[1])
            # Verifica se o endereço do arquivo é válido
            if (type(path_file) == str) and (".yml" in path_file):
                try:
                    # Abre o arquivo
                    file_yml = open(path_file, "r")
                    # Converte o arquivo em objeto
                    file_open = yaml.load(file_yml)
                except Exception as inst:
                    self.status.error("CONFIGURATION_SERVICE", None,
                                      ["Arquivo de configuracao nao encontrado"])
                    config_local = None

            # Verifica se o arquivo é válido e se existe configurações de serviços nele
            if (file_open is not None) and ("services" in file_open.keys()):
                # Processa o arquivo
                for item in file_open["services"]:
                    services = file_open["services"][item]
                    if "environment" in services:
                        environment = services["environment"]
                        if "devdoo" in environment:
                            devdoo = environment["devdoo"]
                            devdoo = Convert.to_object(devdoo)
                            if Check.is_object(devdoo):
                                # Recupera as configurações devdoo necessárias
                                config_local = devdoo
                            else:
                                self.status.error("CONFIGURATION_SERVICE", None,
                                                  ["Arquivo de configuracao nao e um 'object' valido"])
                        else:
                            self.status.error("CONFIGURATION_SERVICE", None,
                                              ["Arquivo de configuracao encontrou falhas no grupo 'devdoo'"])
                    else:
                        self.status.error("CONFIGURATION_SERVICE", None,
                                          ["Arquivo de configuracao encontrou falhas no grupo 'environment'"])
            else:
                self.status.error("CONFIGURATION_SERVICE", None,
                                  ["Arquivo de configuracao não possui o grupo 'services'"])
        else:
            self.status.error("CONFIGURATION_SERVICE", None,
                              ["Nao foi indicado nenhum endereco de arquivo de configuracao"])
        return config_local



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

setup(name='packagetest90',
      version='0.90',
      description='Test3',
      url='http://github.com/storborg/funniest',
      author='PulStar',
      author_email='pulstar@gmail.com',
      license='MIT',
      packages=['devdoo', 'devdoo/i18n', 'devdoo/yaml'],
      zip_safe=False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket

HOST_NAME = socket.gethostname()
HOST_IP = socket.gethostbyname(HOST_NAME)
BROKER_IP = 'localhost'
if HOST_IP[:3] == '10.':
    BROKER_IP = '10.10.0.1'

print 'HOSTNAME:', HOST_NAME
print 'HOST IP:', HOST_IP
print 'BROKER_IP:', BROKER_IP

BROKER_DATABASE_ENDPOINT_A = 'tcp://localhost:41234'
BROKER_DATABASE_ENDPOINT_B = 'tcp://localhost:41640'
BROKER_DATABASE_ENDPOINT_C = 'tcp://localhost:43210'
MONGO_IP = 'localhost'
if HOST_IP[:3] == '10.':
    BROKER_DATABASE_ENDPOINT_A = 'tcp://10.30.0.1:41234'
    BROKER_DATABASE_ENDPOINT_B = 'tcp://10.30.0.1:41640'
    BROKER_DATABASE_ENDPOINT_C = 'tcp://10.30.0.1:43210'
    MONGO_IP = '10.50.0.1'

print 'HOSTNAME:', HOST_NAME
print 'HOST IP:', HOST_IP
print 'BROKER_DATABASE_ENDPOINT_A:', BROKER_DATABASE_ENDPOINT_A
print 'BROKER_DATABASE_ENDPOINT_B:', BROKER_DATABASE_ENDPOINT_B
print 'BROKER_DATABASE_ENDPOINT_C:', BROKER_DATABASE_ENDPOINT_C
print 'MONGO_IP:', MONGO_IP

import socket

HOST_NAME = socket.gethostname()
HOST_IP = socket.gethostbyname(HOST_NAME)
BROKER_REST_ENDPOINT = 'tcp://localhost:23210'
BROKER_DATABASE_ENDPOINT = 'tcp://localhost:30188'

# Verifica se esta executando no Docker ou On-line
if HOST_IP[:3] == '10.':
    BROKER_REST_ENDPOINT = 'tcp://10.10.0.1:23210'
    BROKER_DATABASE_ENDPOINT = 'tcp://10.30.0.1:30188'

print 'HOSTNAME:', HOST_NAME
print 'HOST IP:', HOST_IP
print 'BROKER_REST_ENDPOINT:', BROKER_REST_ENDPOINT
print 'BROKER_DATABASE_ENDPOINT:', BROKER_DATABASE_ENDPOINT

# load_devdoo_brokers
server_console = {
    "5abe46fd83566949ecc10121": {
        "id": "5abe46fd83566949ecc10121",
        "name": "Broker-RS90",
        "type": "devdoo-brokers",
        "network": {
            "ip": "",
            "port": "10121"
        },
        "version": 1.0,
        "services":
            [
                {
                    "id": "7b85814a9f68d0ad190c4d84",
                    "name": "domains",
                    "ip": BROKER_IP,
                    "service_id": "21234",
                    "connections": 0,
                    "errors": 0
                },
                {
                    "id": "7b85814a9f68d0ad190c4d84",
                    "name": "log",
                    "ip": BROKER_IP,
                    "service_id": "23210",
                    "connections": 0,
                    "errors": 0
                },
                {
                    "id": "7b85814a9f68d0ad190c4d84",
                    "name": "dental",
                    "ip": BROKER_IP,
                    "service_id": "21640",
                    "connections": 0,
                    "errors": 0
                }
            ]},
    "5abe46fd83566949ecc30188": {
        "id": "5abe46fd83566949ecc30188",
        "name": "Broker-DB45",
        "type": "devdoo-brokers",
        "network": {
            "ip": "",
            "port": "30188"
        },
        "version": 1.0,
        "services": [
            {
                "id": "7b85814a9f68d0ad190c4d86",
                "name": "domains",
                "service_id": "41234",
                "connections": 0,
                "errors": 0
            },
            {
                "id": "7b85814a9f68d0ad190c4d86",
                "name": "log",
                "service_id": "43210",
                "connections": 0,
                "errors": 0
            },
            {
                "id": "7b85814a9f68d0ad190c4d86",
                "name": "dental",
                "service_id": "41640",
                "connections": 0,
                "errors": 0
            }
        ]
    },
    "41234":
        {
            "id": "9885814a9f68d0ad190c4d79",
            "name": "domains",
            "broker_database_endpoint": BROKER_DATABASE_ENDPOINT_A,
            "mongodb_ip": MONGO_IP,
            "mongodb_port": 27017,
            "service_id": "41234",
            "connections": 0,
            "errors": 0
        },
    "41640":
        {
            "id": "a885814a9f68d0ad190c4d7a",
            "name": "dental",
            "broker_database_endpoint": BROKER_DATABASE_ENDPOINT_B,
            "mongodb_ip": MONGO_IP,
            "mongodb_port": 27017,
            "service_id": "41640",
            "connections": 0,
            "errors": 0
        },
    "5abe46fd83566949ecc43210":
        {
            "id": "a885814a9f68d0ad190c4d7a",
            "name": "log",
            "broker_database_endpoint": BROKER_DATABASE_ENDPOINT_C,
            "mongodb_ip": MONGO_IP,
            "mongodb_port": 27017,
            "service_id": "43210",
            "connections": 0,
            "errors": 0
        },

    "5abe46fd83566949ecc23210":
        {
            "id": "5abe46fd83566949ecc23210",
            "name": "log",
            "type": "devdoo-service",
            "network": {
                "ip": "",  # ip da instância
                "port": "23210"  # porta do serviço log no primeiro broker (rest)
            },
            "version": 1.0,  # versão
            "database": {
                "id": "6355814a9f68d0ad190c4d53",
                "network": {
                    "ip": "",  # ip da instância
                    "port": "43210"  # porta do serviço log no primeiro broker (rest)
                },
                "collections": {
                    "messages": {
                        "name": "messages",  # nome da coleção
                        "id": "6355814a9f68d0ad190c4d54",  # id da coleção
                        "schemes": {  # detalhes de configuração dos campos da coleção (schema)
                            "type_array": {"id": "6355814a9f68d0ad190c1001", "field": "type_array", "type": "array", "info": "Array",
                                           "version": "1.0", "public": True},
                            "type_boolean": {"id": "6355814a9f68d0ad190c1002", "field": "type_boolean", "type": "boolean", "info": "Boolean",
                                             "version": "1.0", "public": True},
                            "type_number": {"id": "6355814a9f68d0ad190c1003", "field": "type_number", "type": "number", "info": "Number",
                                            "version": "1.0", "min_value": "100", "max_value": "3000", "required": "true", "public": True},
                            "type_decimal": {"id": "6355814a9f68d0ad190c1004", "field": "type_decimal", "type": "decimal", "info": "Number Decimal",
                                             "version": "1.0", "public": True},
                            "type_object": {"id": "6355814a9f68d0ad190c1005", "field": "type_object", "type": "object", "info": "Object",
                                            "version": "1.0", "public": False},
                            "type_timestamp": {"id": "6355814a9f68d0ad190c1006", "field": "type_timestamp", "type": "timestamp", "info": "Timestamp",
                                               "version": "1.0", "public": True},
                            "type_objectid": {"id": "6355814a9f68d0ad190c1007", "field": "type_objectid", "type": "object_id", "info": "ObjectId",
                                              "version": "1.0", "public": True},
                            "type_enum": {"id": "6355814a9f68d0ad190c1008", "field": "type_enum", "type": "enum", "info": "Enum", "version": "1.0",
                                          "enum": ["M", "F", "34"], "public": False},
                            "type_string": {"id": "6355814a9f68d0ad190c1009", "field": "type_string", "type": "string", "info": "String",
                                            "version": "1.0", "public": False},
                            "type_date": {"id": "6355814a9f68d0ad190c1010", "field": "type_date", "type": "date", "info": "Date", "version": "1.0",
                                          "public": False},
                            "code": {"id": "6355814a9f68d0ad190c1011", "field": "code", "type": "number", "info": "Código do erro", "version": "1.0",
                                     "public": True},
                            "script": {"id": "6355814a9f68d0ad190c1012", "field": "script", "type": "object", "info": "Nome do script",
                                       "version": "1.0", "public": False},
                            "container": {"id": "6355814a9f68d0ad190c1013", "field": "container", "type": "object", "info": "ID do container",
                                          "version": "1.0", "public": True},
                            "instance": {"id": "6355814a9f68d0ad190c1014", "field": "instance", "type": "object", "info": "ID da instância",
                                         "version": "1.0", "public": True},
                            "created_at": {"id": "6355814a9f68d0ad190c1015", "field": "created_at", "type": "date", "info": "Horário da ocorrência",
                                           "version": "1.0", "public": False},
                            "user": {"id": "6355814a9f68d0ad190c1016", "field": "user", "type": "object", "info": "Código do usuário",
                                     "version": "1.0", "public": True},
                            "service": {"id": "6355814a9f68d0ad190c1017", "field": "service", "type": "object", "info": "Código do serviço",
                                        "version": "1.0", "public": False},
                            "type": {"id": "6355814a9f68d0ad190c1018", "field": "type", "type": "string", "info": "Tipo do (error|warn|info|log)",
                                     "version": "1.0", "public": True},
                            "message": {"id": "6355814a9f68d0ad190c1019", "field": "message", "type": "string", "info": "Detalhes extras",
                                        "version": "1.0", "public": False}
                        }
                    }
                },
                "actions": {
                    "get": {
                        # --------------------------------
                        # messages
                        # --------------------------------
                        "/1.0/devdoo/log/system/messages": {
                            "fields": {
                                "default": [
                                    "type_array",
                                    "type_boolean",
                                    "type_number",
                                    "type_decimal",
                                    "type_object",
                                    "type_timestamp",
                                    "type_objectid",
                                    "type_enum",
                                    "type_string",
                                    "type_date",
                                    "type_bola",
                                    "code",
                                    "script",
                                    "container",
                                    "created_at",
                                    "user",
                                    "service",
                                    "type",
                                    "message"
                                ],
                                "public": []
                            },
                            "scheme": {},
                            "action": "find",
                            "collection": "messages",
                            "type": "list",
                            "max_limit": 100
                        }
                    },
                    "put": {
                        # --------------------------------
                        # mensagens
                        # --------------------------------
                        "/1.0/devdoo/log/system/edit-message": {

                            "fields": {
                                "default": [
                                    "type_array",
                                    "type_boolean",
                                    "type_number",
                                    "type_decimal",
                                    "type_object",
                                    "type_timestamp",
                                    "type_objectid",
                                    "type_enum",
                                    "type_string",
                                    "type_date",
                                    "type_bola",
                                    "code",
                                    "script",
                                    "container",
                                    "created_at",
                                    "user",
                                    "service",
                                    "type",
                                    "message"
                                ],
                                "public": []
                            },
                            "scheme": {
                                "$set": [
                                    "type_array",
                                    "type_boolean",
                                    "type_number"
                                ]
                            },
                            "action": "insert",
                            "collection": "messages",
                            "type": "item",
                            "max_limit": 1
                        }
                    },
                    "post": {
                        # --------------------------------
                        # mensagens
                        # --------------------------------
                        "/1.0/devdoo/log/system/add-message": {

                            "fields": {
                                "default": [
                                    "type_array",
                                    "type_boolean",
                                    "type_number",
                                    "type_decimal",
                                    "type_object",
                                    "type_timestamp",
                                    "type_objectid",
                                    "type_enum",
                                    "type_string",
                                    "type_date",
                                    "type_bola",
                                    "code",
                                    "script",
                                    "container",
                                    "created_at",
                                    "user",
                                    "service",
                                    "type",
                                    "message"
                                ],
                                "public": []
                            },
                            "scheme": {},
                            "action": "insert",  # TODO: Mudar o nome da operação de database para operation
                            "collection": "messages",
                            "type": "item",
                            "max_limit": 100
                        }

                    },
                    "delete": {
                        # --------------------------------
                        # mensagens
                        # --------------------------------
                        "/1.0/devdoo/log/system/remove-message": {

                            "fields": {
                                "default": [],
                                "public": []
                            },
                            "scheme": {},
                            "collection": "messages",
                            "action": "remove",
                            "type": "list",
                            "max_limit": 100
                        }
                    }
                }
            },
            "endpoints": {
                "broker_rest": BROKER_REST_ENDPOINT,
                "broker_database": BROKER_DATABASE_ENDPOINT
            }
        }
}


# TODO:: Mudar estutura de configuração de scheme e actions
class Console:
    def load_config(self, id):
        return server_console[id]

    def ready(self):
        return True
